/*******************************************************************************
* File Name: Character_LCD_LCDPort.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Character_LCD_LCDPort.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        Character_LCD_LCDPort_PC =   (Character_LCD_LCDPort_PC & \
                                (uint32)(~(uint32)(Character_LCD_LCDPort_DRIVE_MODE_IND_MASK << (Character_LCD_LCDPort_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (Character_LCD_LCDPort_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: Character_LCD_LCDPort_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void Character_LCD_LCDPort_Write(uint8 value) 
{
    uint8 drVal = (uint8)(Character_LCD_LCDPort_DR & (uint8)(~Character_LCD_LCDPort_MASK));
    drVal = (drVal | ((uint8)(value << Character_LCD_LCDPort_SHIFT) & Character_LCD_LCDPort_MASK));
    Character_LCD_LCDPort_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: Character_LCD_LCDPort_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  Character_LCD_LCDPort_DM_STRONG     Strong Drive 
*  Character_LCD_LCDPort_DM_OD_HI      Open Drain, Drives High 
*  Character_LCD_LCDPort_DM_OD_LO      Open Drain, Drives Low 
*  Character_LCD_LCDPort_DM_RES_UP     Resistive Pull Up 
*  Character_LCD_LCDPort_DM_RES_DWN    Resistive Pull Down 
*  Character_LCD_LCDPort_DM_RES_UPDWN  Resistive Pull Up/Down 
*  Character_LCD_LCDPort_DM_DIG_HIZ    High Impedance Digital 
*  Character_LCD_LCDPort_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void Character_LCD_LCDPort_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(Character_LCD_LCDPort__0__SHIFT, mode);
	SetP4PinDriveMode(Character_LCD_LCDPort__1__SHIFT, mode);
	SetP4PinDriveMode(Character_LCD_LCDPort__2__SHIFT, mode);
	SetP4PinDriveMode(Character_LCD_LCDPort__3__SHIFT, mode);
	SetP4PinDriveMode(Character_LCD_LCDPort__4__SHIFT, mode);
	SetP4PinDriveMode(Character_LCD_LCDPort__5__SHIFT, mode);
	SetP4PinDriveMode(Character_LCD_LCDPort__6__SHIFT, mode);
}


/*******************************************************************************
* Function Name: Character_LCD_LCDPort_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Character_LCD_LCDPort_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Character_LCD_LCDPort_Read(void) 
{
    return (uint8)((Character_LCD_LCDPort_PS & Character_LCD_LCDPort_MASK) >> Character_LCD_LCDPort_SHIFT);
}


/*******************************************************************************
* Function Name: Character_LCD_LCDPort_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Character_LCD_LCDPort_ReadDataReg(void) 
{
    return (uint8)((Character_LCD_LCDPort_DR & Character_LCD_LCDPort_MASK) >> Character_LCD_LCDPort_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Character_LCD_LCDPort_INTSTAT) 

    /*******************************************************************************
    * Function Name: Character_LCD_LCDPort_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Character_LCD_LCDPort_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(Character_LCD_LCDPort_INTSTAT & Character_LCD_LCDPort_MASK);
		Character_LCD_LCDPort_INTSTAT = maskedStatus;
        return maskedStatus >> Character_LCD_LCDPort_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
