/*******************************************************************************
* File Name: GSMSig.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "GSMSig.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        GSMSig_PC =   (GSMSig_PC & \
                                (uint32)(~(uint32)(GSMSig_DRIVE_MODE_IND_MASK << (GSMSig_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (GSMSig_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: GSMSig_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void GSMSig_Write(uint8 value) 
{
    uint8 drVal = (uint8)(GSMSig_DR & (uint8)(~GSMSig_MASK));
    drVal = (drVal | ((uint8)(value << GSMSig_SHIFT) & GSMSig_MASK));
    GSMSig_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: GSMSig_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  GSMSig_DM_STRONG     Strong Drive 
*  GSMSig_DM_OD_HI      Open Drain, Drives High 
*  GSMSig_DM_OD_LO      Open Drain, Drives Low 
*  GSMSig_DM_RES_UP     Resistive Pull Up 
*  GSMSig_DM_RES_DWN    Resistive Pull Down 
*  GSMSig_DM_RES_UPDWN  Resistive Pull Up/Down 
*  GSMSig_DM_DIG_HIZ    High Impedance Digital 
*  GSMSig_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void GSMSig_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(GSMSig__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: GSMSig_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro GSMSig_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 GSMSig_Read(void) 
{
    return (uint8)((GSMSig_PS & GSMSig_MASK) >> GSMSig_SHIFT);
}


/*******************************************************************************
* Function Name: GSMSig_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 GSMSig_ReadDataReg(void) 
{
    return (uint8)((GSMSig_DR & GSMSig_MASK) >> GSMSig_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(GSMSig_INTSTAT) 

    /*******************************************************************************
    * Function Name: GSMSig_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 GSMSig_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(GSMSig_INTSTAT & GSMSig_MASK);
		GSMSig_INTSTAT = maskedStatus;
        return maskedStatus >> GSMSig_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
