/*
  Project: Testing GSM SIM300 Module
  Author: Shaunak Vyas
  Description: The project sends an "AT" command to the GSM Module and receives "OK"
               as acknowledgment.
  Email: neecshaunak@gmail.com
*/
#include <project.h>
#include <stdlib.h>
#include <string.h>

#define SET 1u
#define CLEAR 0u
#define FSM_WAITING_TO_READ 0u
#define FSM_READING 1u
#define FSM_WAITING_TO_CONSUME_NL 2u

//Interrupt Service Routines
CY_ISR_PROTO (ISRGSMRxHandler);
CY_ISR_PROTO (ISRSGSMHandler); //Sending Message on Signal Read


//Variable declaration

char sim300_buffer[128];
char ch;
uint8 p = 0;
uint8 string_receive_status = CLEAR;
char AT1[3] = {'A','T',0x0D};  /*  Command: AT 'Carriage Return' */
void SIM300sendcommand(char *commandstring);
uint8 GSM_Signal_Status = CLEAR;
int i, stringlen;
unsigned int fsm = FSM_WAITING_TO_READ;


void SIM300sendcommand(char *commandstring)
{
    stringlen = strlen(commandstring);
    for(i = 0; i < stringlen; i++)
    {
        UART_UartPutChar(*(commandstring + i));
    }
}    

void Halt();
int main(void)
{
    CyGlobalIntEnable;
    UART_Start();
    ISR_UART_StartEx(ISRGSMRxHandler);
    ISR_GSMSig_StartEx(ISRSGSMHandler);
	//Initialize LCD Module
	Character_LCD_Start();;
	
	//Intro Message
    Character_LCD_Position(0u,0u);
	Character_LCD_PrintString("SIM300 Demo !");
    Character_LCD_Position(1u,0u);
	Character_LCD_PrintString("NEEC");
	
	CyDelay(5000);
	
	Character_LCD_ClearDisplay();	
	
	UART_SpiUartClearRxBuffer();
	
	while(1)
	{
        if(GSM_Signal_Status == SET)
        {
            Character_LCD_ClearDisplay();
            Character_LCD_Position(0,0);
	        Character_LCD_PrintString(AT1);
            SIM300sendcommand(AT1);
            CyDelay(1000);
            GSM_Signal_Status = CLEAR;
        }    
    }
}    
CY_ISR(ISRGSMRxHandler)
{
    UART_rx_ClearInterrupt();
    ch = UART_UartGetChar();
    switch(fsm){
        case FSM_WAITING_TO_READ:
            // check if newline
            if(ch == 0x0a){
                fsm = FSM_READING;
            }
            break;
        case FSM_READING:
            // check if carriage return
            if(ch == 0x0d){
                sim300_buffer[p] = 0;
                string_receive_status = SET;
                Character_LCD_Position(1u,0u);
                Character_LCD_PrintString(sim300_buffer);
                p = 0;
                fsm = FSM_WAITING_TO_CONSUME_NL;
            } else {
                sim300_buffer[p++] = ch;
/*                
                Character_LCD_Position(1u,p);
                Character_LCD_PutChar(sim300_buffer[p]);
*/                
            }
            break;
        case FSM_WAITING_TO_CONSUME_NL:
            // consume additional last newline
            fsm = FSM_WAITING_TO_READ;
            break;
        default:
            break;
    }

}
CY_ISR(ISRSGSMHandler)
{
    GSM_Signal_Status = SET;    
    GSMSig_ClearInterrupt();
//-----    ISR_GSMSig_Stop();
}
